/*
* Jalview - A Sequence Alignment Editor and Viewer
* Copyright (C) 2005 AM Waterhouse, J Procter, G Barton, M Clamp, S Searle
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
*/
package jalview.gui;

import javax.swing.*;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.BorderLayout;
import java.awt.*;

import jalview.schemes.*;

public class AnnotationColourChooser
    extends JPanel
{
  JInternalFrame frame;
  AlignViewport av;
  AlignmentPanel ap;
  ColourSchemeI oldcs;

  public AnnotationColourChooser(AlignViewport av, AlignmentPanel ap)
  {
    oldcs = av.getGlobalColourScheme();
    this.av = av;
    this.ap = ap;
    frame = new JInternalFrame();
    frame.setContentPane(this);
    frame.setLayer(JLayeredPane.PALETTE_LAYER);
    Desktop.addInternalFrame(frame, "Colour by Annotation", 480, 110);

    try{
      jbInit();
    }catch(Exception ex){}

    if(av.alignment.getAlignmentAnnotation()==null)
      return;

    for(int i=0; i<av.alignment.getAlignmentAnnotation().length; i++)
    {
      annotations.addItem(av.alignment.getAlignmentAnnotation()[i].label);
    }

  //  if(av.getGlobalColourScheme() instanceof AnnotationColourGradient)
    {
    //  minColour.
    }
  //  else
    {
      minColour.setBackground(Color.orange);
      maxColour.setBackground(Color.red);
    }
  }

  public AnnotationColourChooser()
  {
    try
    {
      jbInit();
    }
    catch (Exception ex)
    {
      ex.printStackTrace();
    }
  }

  private void jbInit()
      throws Exception
  {
    minColour.setBounds(new Rectangle(145, 5, 85, 25));
    minColour.setToolTipText("");
    minColour.setMargin(new Insets(2, 2, 2, 2));
    minColour.setText("Min Colour");
    minColour.addActionListener(new ActionListener()
    {
      public void actionPerformed(ActionEvent e)
      {
        minColour_actionPerformed(e);
      }
    });
    maxColour.setBounds(new Rectangle(235, 5, 89, 25));
    maxColour.setMargin(new Insets(2, 2, 2, 2));
    maxColour.setText("Max Colour");
    maxColour.addActionListener(new ActionListener()
    {
      public void actionPerformed(ActionEvent e)
      {
        maxColour_actionPerformed(e);
      }
    });
    thresholdCheck.setOpaque(false);
    thresholdCheck.setHorizontalTextPosition(SwingConstants.LEADING);
    thresholdCheck.setSelectedIcon(null);
    thresholdCheck.setText("Above Threshold");
    thresholdCheck.setBounds(new Rectangle(329, 6, 109, 23));
    apply.setOpaque(false);
    apply.setSelectedIcon(null);
    apply.setText("Apply");
    apply.addActionListener(new ActionListener()
    {
      public void actionPerformed(ActionEvent e)
      {
        apply_actionPerformed(e);
      }
    });
    ok.setOpaque(false);
    ok.setText("OK");
    ok.addActionListener(new ActionListener()
    {
      public void actionPerformed(ActionEvent e)
      {
        ok_actionPerformed(e);
      }
    });
    cancel.setOpaque(false);
    cancel.setText("Cancel");
    cancel.addActionListener(new ActionListener()
    {
      public void actionPerformed(ActionEvent e)
      {
        cancel_actionPerformed(e);
      }
    });
    this.setLayout(borderLayout1);
    jPanel2.setLayout(null);
    annotations.setBounds(new Rectangle(5, 7, 135, 21));
    jPanel1.setBackground(Color.white);
    jPanel2.setBackground(Color.white);
    jPanel1.add(apply);
    jPanel1.add(ok);
    jPanel1.add(cancel);
    jPanel2.add(annotations);
    jPanel2.add(minColour);
    jPanel2.add(maxColour);
    jPanel2.add(thresholdCheck);
    this.add(jPanel1, java.awt.BorderLayout.SOUTH);
    this.add(jPanel2, java.awt.BorderLayout.CENTER);
  }

  JComboBox annotations = new JComboBox();
  JButton minColour = new JButton();
  JButton maxColour = new JButton();
  JCheckBox thresholdCheck = new JCheckBox();
  JButton apply = new JButton();
  JButton ok = new JButton();
  JButton cancel = new JButton();
  JPanel jPanel1 = new JPanel();
  JPanel jPanel2 = new JPanel();
  BorderLayout borderLayout1 = new BorderLayout();
  public void apply_actionPerformed(ActionEvent e)
  {
    changeColour();
  }

  public void minColour_actionPerformed(ActionEvent e)
  {
    Color col = JColorChooser.showDialog(this,
                                         "Select Colour for Minimum Value",
                                         minColour.getBackground());
    if (col != null)
      minColour.setBackground(col);
    minColour.repaint();
  }

  public void maxColour_actionPerformed(ActionEvent e)
  {
    Color col = JColorChooser.showDialog(this,
                                         "Select Colour for Maximum Value",
                                         maxColour.getBackground());
    if (col != null)
      maxColour.setBackground(col);
    maxColour.repaint();
  }

  void changeColour()
  {
    jalview.datamodel.AlignmentAnnotation aa = av.alignment.getAlignmentAnnotation()[annotations.getSelectedIndex()];

    AnnotationColourGradient acg = new AnnotationColourGradient(aa,
     minColour.getBackground(),
     maxColour.getBackground(),
     thresholdCheck.isSelected());

   if(thresholdCheck.isSelected() && aa.graphLines==null)
   {
     aa.addGraphLine(new jalview.datamodel.GraphLine((aa.graphMax-aa.graphMin)/2f, "Threshold", Color.black));
   }

   av.setGlobalColourScheme(acg);
   ap.repaint();

  }

  public void ok_actionPerformed(ActionEvent e)
  {
    changeColour();
    try{
      frame.setClosed(true);
    }catch(Exception ex){}
  }

  public void cancel_actionPerformed(ActionEvent e)
  {
    av.setGlobalColourScheme(oldcs);
    try{
      frame.setClosed(true);
    }catch(Exception ex){}
  }

}
